@@ -1,7 +1,7 @@
 import requests
 
 
-class MyException(Exception):
+class Exception(Exception):
     pass
 
 
